@@ -17,7 +17,6 @@ my %config = (
 
 my @balance = Finance::Bank::IE::PermanentTSB->check_balance(\%config);
 
-print Dumper(@balance);
 foreach my $acc (@balance) {
     printf ("%s ending with %s: %s\n", 
         $acc->{'accname'},
@@ -29,4 +28,12 @@ foreach my $acc (@balance) {
 my @statement = Finance::Bank::IE::PermanentTSB->account_statement(
     \%config,'Switch Current A/C - 2667','2008/12/01','2008/12/31');
 
+foreach my $row (@statement) {
+    printf("%s | %s | %s | %s \n",
+        $row->{date},
+        $row->{description},
+        $row->{euro_amount},
+        $row->{balance});
+}
+
 Finance::Bank::IE::PermanentTSB->logoff(\%config);
